@@ -376,7 +376,7 @@ int agent_set_remote_gathering_done(juice_agent_t *agent) {
 }
 
 int agent_send(juice_agent_t *agent, const char *data, size_t size, int ds) {
-	// Do not lock the global mutex in the send path as it would be deadlock-prone for the user
+	// Try not to lock the global mutex in the send path
 	agent_stun_entry_t *selected_entry = atomic_load(&agent->selected_entry);
 	if (!selected_entry) {
 		JLOG_ERROR("Send called before ICE is connected");
@@ -625,27 +625,21 @@ void agent_run(juice_agent_t *agent) {
 		if (timediff < 0)
 			timediff = 0;
 
-		JLOG_VERBOSE("Setting select timeout to %ld ms", (long)timediff);
-		struct timeval timeout;
-		timeout.tv_sec = (long)(timediff / 1000);
-		timeout.tv_usec = (long)((timediff % 1000) * 1000);
+		struct pollfd pfd[1];
+		pfd[0].fd = agent->sock;
+		pfd[0].events = POLLIN;
 
-		fd_set readfds;
-		FD_ZERO(&readfds);
-		FD_SET(agent->sock, &readfds);
-		int n = SOCKET_TO_INT(agent->sock) + 1;
-
-		JLOG_VERBOSE("Entering select");
+		JLOG_VERBOSE("Entering poll for %d ms", (int)timediff);
 		mutex_unlock(&agent->mutex);
-		int ret = select(n, &readfds, NULL, NULL, &timeout);
+		int ret = poll(pfd, 1, (int)timediff);
 		mutex_lock(&agent->mutex);
-		JLOG_VERBOSE("Leaving select");
+		JLOG_VERBOSE("Leaving poll");
 		if (ret < 0) {
 			if (sockerrno == SEINTR || sockerrno == SEAGAIN) {
-				JLOG_VERBOSE("select interrupted");
+				JLOG_VERBOSE("poll interrupted");
 				continue;
 			} else {
-				JLOG_FATAL("select failed, errno=%d", sockerrno);
+				JLOG_FATAL("poll failed, errno=%d", sockerrno);
 				break;
 			}
 		}
@@ -655,7 +649,12 @@ void agent_run(juice_agent_t *agent) {
 			break;
 		}
 
-		if (FD_ISSET(agent->sock, &readfds)) {
+		if(pfd[0].revents & POLLNVAL || pfd[0].revents & POLLERR) {
+			JLOG_FATAL("Error when polling socket");
+			break;
+		}
+
+		if (pfd[0].revents & POLLIN) {
 			if (agent_recv(agent) < 0)
 				break;
 		}
@@ -1402,8 +1401,12 @@ int agent_process_stun_binding(juice_agent_t *agent, const stun_message_t *msg,
 		break;
 	}
 	case STUN_CLASS_RESP_ERROR: {
-		if (msg->error_code != STUN_ERROR_INTERNAL_VALIDATION_FAILED)
-			JLOG_WARN("Got STUN Binding error response, code=%u", (unsigned int)msg->error_code);
+		if (msg->error_code != STUN_ERROR_INTERNAL_VALIDATION_FAILED) {
+			if(msg->error_code == 487)
+				JLOG_DEBUG("Got STUN Binding error response, code=%u", (unsigned int)msg->error_code);
+			else
+				JLOG_WARN("Got STUN Binding error response, code=%u", (unsigned int)msg->error_code);
+		}
 
 		if (entry->type == AGENT_STUN_ENTRY_TYPE_CHECK) {
 			if (msg->error_code == 487) {
@@ -1424,15 +1427,15 @@ int agent_process_stun_binding(juice_agent_t *agent, const stun_message_t *msg,
 					agent_update_candidate_pairs(agent);
 
 					juice_random(&agent->ice_tiebreaker, sizeof(agent->ice_tiebreaker));
+					if (entry->state != AGENT_STUN_ENTRY_STATE_IDLE) { // Check might not be started
+						entry->state = AGENT_STUN_ENTRY_STATE_PENDING;
+						agent_arm_transmission(agent, entry, 0);
+					}
 				} else {
 					JLOG_DEBUG("Already switched roles to %s as requested",
 					           agent->mode == AGENT_MODE_CONTROLLING ? "controlling"
 					                                                 : "controlled");
 				}
-
-				entry->state = AGENT_STUN_ENTRY_STATE_PENDING;
-				agent_arm_transmission(agent, entry, 0);
-
 			} else {
 				// 7.2.5.2.4. Unrecoverable STUN Response:
 				// If the Binding request generates a STUN error response that is unrecoverable
@@ -1491,8 +1494,8 @@ int agent_send_stun_binding(juice_agent_t *agent, agent_stun_entry_t *entry, stu
 		switch (msg_class) {
 		case STUN_CLASS_REQUEST: {
 			if (*agent->remote.ice_ufrag == '\0' || *agent->remote.ice_pwd == '\0') {
-				JLOG_ERROR("Attempted to send STUN Binding to peer without remote ICE credentials");
-				return -1;
+				JLOG_DEBUG("Missing remote ICE credentials, dropping STUN binding request");
+				return 0;
 			}
 			snprintf(msg.credentials.username, STUN_MAX_USERNAME_LEN, "%s:%s",
 			         agent->remote.ice_ufrag, agent->local.ice_ufrag);
