@@ -19,10 +19,6 @@
 #ifndef JUICE_AGENT_H
 #define JUICE_AGENT_H
 
-#ifdef __STDC_NO_ATOMICS__
-#define NO_ATOMICS
-#endif
-
 #include "addr.h"
 #include "ice.h"
 #include "juice.h"
@@ -35,10 +31,6 @@
 #include <stdbool.h>
 #include <stdint.h>
 
-#ifndef NO_ATOMICS
-#include <stdatomic.h>
-#endif
-
 // RFC 8445: Agents MUST NOT use an RTO value smaller than 500 ms.
 #define MIN_STUN_RETRANSMISSION_TIMEOUT 500 // msecs
 #define MAX_STUN_RETRANSMISSION_COUNT 5     // count (exponential backoff, will give ~30s)
@@ -120,11 +112,7 @@ typedef struct agent_stun_entry {
 	unsigned int turn_redirections;
 	struct agent_stun_entry *relay_entry;
 
-#ifdef NO_ATOMICS
-	volatile bool armed;
-#else
-	atomic_flag armed;
-#endif
+	atomic(bool) armed;
 } agent_stun_entry_t;
 
 struct juice_agent {
@@ -145,11 +133,7 @@ struct juice_agent {
 
 	agent_stun_entry_t entries[MAX_STUN_ENTRIES_COUNT];
 	int entries_count;
-#ifdef NO_ATOMICS
-	agent_stun_entry_t *volatile selected_entry;
-#else
-	_Atomic(agent_stun_entry_t *) selected_entry;
-#endif
+	atomic_ptr(agent_stun_entry_t) selected_entry;
 
 	uint64_t ice_tiebreaker;
 	timestamp_t fail_timestamp;
@@ -198,9 +182,9 @@ int agent_dispatch_stun(juice_agent_t *agent, void *buf, size_t size, stun_messa
 int agent_process_stun_binding(juice_agent_t *agent, const stun_message_t *msg,
                                agent_stun_entry_t *entry, const addr_record_t *src,
                                const addr_record_t *relayed); // relayed may be NULL
-int agent_send_stun_binding(juice_agent_t *agent, agent_stun_entry_t *entry,
-                            stun_class_t msg_class, unsigned int error_code,
-                            const uint8_t *transaction_id, const addr_record_t *mapped);
+int agent_send_stun_binding(juice_agent_t *agent, agent_stun_entry_t *entry, stun_class_t msg_class,
+                            unsigned int error_code, const uint8_t *transaction_id,
+                            const addr_record_t *mapped);
 int agent_process_turn_allocate(juice_agent_t *agent, const stun_message_t *msg,
                                 agent_stun_entry_t *entry);
 int agent_send_turn_allocate_request(juice_agent_t *agent, const agent_stun_entry_t *entry,
