@@ -18,8 +18,8 @@
 
 #include "dtlssrtptransport.hpp"
 #include "logcounter.hpp"
-#include "tls.hpp"
 #include "rtp.hpp"
+#include "tls.hpp"
 
 #if RTC_ENABLE_MEDIA
 
@@ -32,12 +32,11 @@ using std::to_string;
 namespace rtc::impl {
 
 static LogCounter COUNTER_MEDIA_TRUNCATED(plog::warning,
-                                               "Number of truncated SRT(C)P packets received");
+                                          "Number of truncated SRT(C)P packets received");
 static LogCounter
     COUNTER_UNKNOWN_PACKET_TYPE(plog::warning,
                                 "Number of RTP packets received with an unknown packet type");
-static LogCounter COUNTER_SRTCP_REPLAY(plog::warning,
-                                            "Number of SRTCP replay packets received");
+static LogCounter COUNTER_SRTCP_REPLAY(plog::warning, "Number of SRTCP replay packets received");
 static LogCounter
     COUNTER_SRTCP_AUTH_FAIL(plog::warning,
                             "Number of SRTCP packets received that failed authentication checks");
@@ -57,8 +56,7 @@ void DtlsSrtpTransport::Init() { srtp_init(); }
 void DtlsSrtpTransport::Cleanup() { srtp_shutdown(); }
 
 DtlsSrtpTransport::DtlsSrtpTransport(shared_ptr<IceTransport> lower,
-                                     shared_ptr<Certificate> certificate,
-                                     optional<size_t> mtu,
+                                     shared_ptr<Certificate> certificate, optional<size_t> mtu,
                                      verifier_callback verifierCallback,
                                      message_callback srtpRecvCallback,
                                      state_callback stateChangeCallback)
@@ -324,6 +322,6 @@ void DtlsSrtpTransport::postHandshake() {
 	mInitDone = true;
 }
 
-} // namespace rtc
+} // namespace rtc::impl
 
 #endif
