@@ -26,18 +26,17 @@
 
 namespace rtc {
 
-MediaChainableHandler::MediaChainableHandler(shared_ptr<MediaHandlerRootElement> root): MediaHandler(), root(root), leaf(root) { }
+MediaChainableHandler::MediaChainableHandler(shared_ptr<MediaHandlerRootElement> root)
+    : MediaHandler(), root(root), leaf(root) {}
 
-MediaChainableHandler::~MediaChainableHandler() {
-	leaf->recursiveRemoveChain();
-}
+MediaChainableHandler::~MediaChainableHandler() { leaf->recursiveRemoveChain(); }
 
 bool MediaChainableHandler::sendProduct(ChainedOutgoingProduct product) {
 	bool result = true;
 	if (product.control) {
 		assert(product.control->type == Message::Control);
 		auto sendResult = send(product.control);
-		if(!sendResult) {
+		if (!sendResult) {
 			LOG_DEBUG << "Failed to send control message";
 		}
 		result = result && sendResult;
@@ -50,7 +49,7 @@ bool MediaChainableHandler::sendProduct(ChainedOutgoingProduct product) {
 				LOG_DEBUG << "Invalid message to send " << i + 1 << "/" << messages->size();
 			}
 			auto sendResult = send(make_message(*message));
-			if(!sendResult) {
+			if (!sendResult) {
 				LOG_DEBUG << "Failed to send message " << i + 1 << "/" << messages->size();
 			}
 			result = result && sendResult;
@@ -89,7 +88,7 @@ message_ptr MediaChainableHandler::handleOutgoingBinary(message_ptr msg) {
 	}
 	auto outgoing = optOutgoing.value();
 	if (outgoing.control) {
-		if(!send(outgoing.control)) {
+		if (!send(outgoing.control)) {
 			LOG_DEBUG << "Failed to send control message";
 		}
 	}
@@ -103,7 +102,7 @@ message_ptr MediaChainableHandler::handleOutgoingBinary(message_ptr msg) {
 		if (!message) {
 			LOG_DEBUG << "Invalid message to send " << i + 1 << "/" << outgoing.messages->size();
 		}
-		if(!send(make_message(*message))) {
+		if (!send(make_message(*message))) {
 			LOG_DEBUG << "Failed to send message " << i + 1 << "/" << outgoing.messages->size();
 		}
 	}
